<?php

declare(strict_types=1);

namespace App\Controller;

use App\Repository\Post\PostRepository;
use Psr\Log\LoggerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Routing\Attribute\Route;

final class DetailPostController extends AbstractController
{
    public function __construct(
        private readonly PostRepository $postRepository,
        private readonly LoggerInterface $logger,
    ) {
    }

    #[Route('/posts/detail/{postId}', name: 'detail_post', requirements: ['postId' => '\d+'])]
    public function detail(int $postId): Response
    {
        $post = $this->postRepository->find($postId);

        if ($post === null) {
            $this->logger->error('Post not found', ['postId' => $postId]);
            throw new NotFoundHttpException('Post not found. Please check the provided ID. If the problem persists, contact the system administrator');
        }

        return $this->render(
            'detail_post/detail.html.twig',
            ['post' => $post]
        );
    }
}
